#
# spec file for package lua51
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lua51
Version:        5.1.5
Release:        14.13
%define major_version 5.1
BuildRequires:  pkg-config
BuildRequires:  readline-devel
BuildRequires:  update-alternatives
PreReq:         update-alternatives
Summary:        Small Embeddable Language with Simple Procedural Syntax
License:        MIT
Group:          System/Libraries
Url:            http://www.lua.org
Source:         http://www.lua.org/ftp/lua-%{version}.tar.gz
Source1:        macros.lua
Source2:        baselibs.conf
Patch0:         %{name}-%{version}-shared.diff
Patch1:         %{name}-%{version}-module-path.diff
Patch3:         %{name}-%{version}-libdir.diff
Patch4:         %{name}-%{version}-pkgconfig.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Lua is a programming language originally designed for extending
applications, but also frequently used as a general-purpose,
stand-alone language.

Lua combines simple procedural syntax (similar to Pascal) with powerful
data description constructs based on associative arrays and extensible
semantics. Lua is dynamically typed, interpreted from byte codes, and
has automatic memory management, making it ideal for configuration,
scripting, and rapid prototyping. Lua is implemented as a small library
of C functions, written in ANSI C, and the implementation goals are
simplicity, efficiency, portability, and low embedding cost.

%package devel
Summary:        Development files for lua
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Conflicts:      lua50-devel
Conflicts:      lua-devel

%description devel
Lua is a programming language originally designed for extending
applications, but also frequently used as a general-purpose,
stand-alone language.

This package contains files needed for embedding lua into your
application.

%package -n liblua5_1
Summary:        Small Embeddable Language with Simple Procedural Syntax
Group:          System/Libraries
Provides:       %{name}-libs = %{version}
Obsoletes:      %{name}-libs <= %{version}

%description -n liblua5_1
Lua is a programming language originally designed for extending
applications, but also frequently used as a general-purpose,
stand-alone language.

Lua combines simple procedural syntax (similar to Pascal) with powerful
data description constructs based on associative arrays and extensible
semantics. Lua is dynamically typed, interpreted from byte codes, and
has automatic memory management, making it ideal for configuration,
scripting, and rapid prototyping. Lua is implemented as a small library
of C functions, written in ANSI C, and the implementation goals are
simplicity, efficiency, portability, and low embedding cost.

%package doc
Summary:        Small Embeddable Language with Simple Procedural Syntax
Group:          System/Libraries
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
Lua is a programming language originally designed for extending
applications, but also frequently used as a general-purpose,
stand-alone language.

Lua combines simple procedural syntax (similar to Pascal) with powerful
data description constructs based on associative arrays and extensible
semantics. Lua is dynamically typed, interpreted from byte codes, and
has automatic memory management, making it ideal for configuration,
scripting, and rapid prototyping. Lua is implemented as a small library
of C functions, written in ANSI C, and the implementation goals are
simplicity, efficiency, portability, and low embedding cost.

%prep
%setup -q -n lua-%{version}
%patch0 -b .shared
%patch1 -p1
%patch3 -p1
%patch4 -p1

%build
sed -i 's:LUA_ROOT2 "LIBDIR/lua/%{major_version}/":LUA_ROOT2 \"%{_lib}/lua/%{major_version}/":' src/luaconf.h
make %{?_smp_mflags} -C src CC="%{__cc}" MYCFLAGS="$RPM_OPT_FLAGS -fPIC -DLUA_USE_LINUX" MYLIBS="-Wl,-E -ldl -lreadline -lhistory -lncurses" V=%{major_version} all

%install
make install INSTALL_TOP="$RPM_BUILD_ROOT%{_prefix}" INSTALL_LIB="$RPM_BUILD_ROOT%{_libdir}" INSTALL_CMOD=$RPM_BUILD_ROOT%{_libdir}/lua/%{major_version} INSTALL_MAN="$RPM_BUILD_ROOT%{_mandir}/man1"
install -D -m644 etc/lua.pc $RPM_BUILD_ROOT%{_libdir}/pkgconfig/lua.pc
for file in lua luac ; do
    mv "%{buildroot}%{_bindir}/${file}"        "%{buildroot}%{_bindir}/${file}%{major_version}"
    mv "%{buildroot}%{_mandir}/man1/${file}.1" "%{buildroot}%{_mandir}/man1/${file}%{major_version}.1"
done
install -d -m 0755 $RPM_BUILD_ROOT%{_libdir}/lua/%{major_version}
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lua/%{major_version}
install -D %{SOURCE1} %buildroot/etc/rpm/macros.lua51

%clean
rm -rf $RPM_BUILD_ROOT

%post
/usr/sbin/update-alternatives --install                                                   \
            %{_bindir}/lua            lua       %{_bindir}/lua%{major_version}         10 \
    --slave %{_bindir}/luac           luac      %{_bindir}/luac%{major_version}           \
    --slave %{_mandir}/man1/lua.1.gz  lua.1.gz  %{_mandir}/man1/lua%{major_version}.1.gz  \
    --slave %{_mandir}/man1/luac.1.gz luac.1.gz %{_mandir}/man1/luac%{major_version}.1.gz

%preun
if [ "$1" = 0 ] ; then
    /usr/sbin/update-alternatives --remove lua %{_bindir}/lua%{major_version}
fi

%post -n liblua5_1 -p /sbin/ldconfig

%postun -n liblua5_1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYRIGHT HISTORY README
%{_mandir}/man1/lua%{major_version}.1*
%{_mandir}/man1/luac%{major_version}.1*
%{_prefix}/bin/lua%{major_version}
%{_prefix}/bin/luac%{major_version}
%dir %{_libdir}/lua
%dir %{_libdir}/lua/%{major_version}
%dir %{_datadir}/lua
%dir %{_datadir}/lua/%{major_version}
/etc/rpm/macros.lua51

%files -n liblua5_1
%defattr(-,root,root)
%{_libdir}/liblua.so.%{major_version}

%files devel
%defattr(-,root,root)
%{_includedir}/lauxlib.h
%{_includedir}/lua.h
%{_includedir}/lua.hpp
%{_includedir}/luaconf.h
%{_includedir}/lualib.h
%{_libdir}/pkgconfig/lua.pc
%{_libdir}/liblua.a
%{_libdir}/liblua.so

%files doc
%defattr(-,root,root)
%doc doc/*

%changelog
* Tue Oct 22 2013 peter.trommler@ohm-hochschule.de
- fix patch lua51-5.1.5-pkgconfig.patch
  * libdl is required not librt
* Mon Oct 21 2013 peter.trommler@ohm-hochschule.de
- refresh patch lua51-5.1.5-module-path.diff
- new patch lua51-5.1.5-pkgconfig.patch
  * fix libraries in pkgconfig file
* Thu May 16 2013 pgajdos@suse.com
- move rpm macros back, but install it in /etc/rpm/macros.lua51
  and call lua5.1 in %%lua_version definition
* Sun May  5 2013 mrdocs@opensuse.org
- move the lua rpm macros to the devel package to avoid conflict
  with lua 5.2
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Jun 18 2012 pgajdos@suse.com
- updated to 5.1.5:
  * bug-fix release, see http://www.lua.org/bugs.html for
    more details
  - > removed upstream-bugfix.patch
* Sat Mar 31 2012 joop.boonen@opensuse.org
- Correction in Provides and Obsolete for lua-libs
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Dec 21 2011 pgajdos@suse.com
- lua51 branched from lua package
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon Jun 14 2010 pgajdos@suse.cz
- removed -L/usr/lib from Libs: in etc/lua.pc [bnc#613497]
- used upstream bugfix patch from http://www.lua.org/download.html
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Mar 23 2010 pgajdos@suse.cz
- modified LUA_PATH_DEFAULT [bnc#589441]: search modules under
  /usr/%%{_lib}/lua/%%{major_version} too
* Sat Dec 12 2009 jengelh@medozas.de
- add baselibs.conf as a source
- package documentation as noarch
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep 16 2009 dmueller@suse.de
- add baselibs.conf
* Mon Jun  8 2009 pgajdos@suse.cz
- package owns /usr/{lib,share}/lua directories from now
- emoved unneeded root.patch
* Thu Sep 11 2008 pgajdos@suse.cz
- updated to 5.1.4: bugfix release
* Wed Jun 11 2008 jfunk@funktronics.ca
- Set LUA_ROOT to /usr and fix INSTALL_CMOD for lib64
- Add RPM macros file
- Allows for lua-<modulename> packages like python, perl, and ruby
* Fri Mar 28 2008 coolo@suse.de
- hint the solver about the package rename
* Wed Mar 26 2008 coolo@suse.de
- do not package/provide the shared lib twice / follow shared lib
  policy
* Tue Feb 19 2008 pgajdos@suse.cz
- created -doc package
- updated to version 5.1.3, bug fix release. Fixed bugs:
  * wrong error message in some concatenations
  * too many variables in an assignment may cause a C stack
    overflow
  * an error in a module loaded through the '-l' option shows no
    traceback
  * gsub may go wild when wrongly called without its third
    argument and with a large subject
  * table.remove removes last element of a table when given
    an out-of-bound index
  * lua_setfenv may crash if called over an invalid object
  * stand-alone interpreter shows incorrect error message when
    the "message" is a coroutine.
  * debug.sethook/gethook may overflow the thread's stack
* Tue Jul 24 2007 pgajdos@suse.cz
- using /sbin/ldconfig in specfile
- updated to version 5.1.2, fixes some bugs:
  * count hook may be called without being set
  * code generated for "-nil", "-true", and "-false" is wrong
  * recursive coroutines may overflow C stack
  * wrong error message in some concatenations
  * very small numbers all collide in the hash function
* Mon Nov 27 2006 mrueckert@suse.de
- package liblua.so as symlink.
* Thu Nov 16 2006 mrueckert@suse.de
- the core package now uses update alternatives to allow installation
  of 5.0.x and 5.1.x
- devel packages will conflict now
* Tue Nov 14 2006 mrueckert@suse.de
- ARGH dont copy and paste!:
  lua-libs should not depend on lua. another run on (#217875)
* Tue Nov 14 2006 mrueckert@suse.de
- really fix the file pattern (#217875)
* Thu Nov  9 2006 mrueckert@suse.de
- splitted out lua-libs so we can install at least both libs
  in parallel. (#217875)
* Thu Oct 19 2006 dmueller@suse.de
- fix wrong prefix in lua.pc
- link liblua with -lm to satisfy unresolved symbols
* Thu Oct 19 2006 mjancar@suse.cz
- include lua.pc
* Wed Oct 18 2006 mjancar@suse.cz
- update to 5.1.1
  Language:
  * new module system.
  * new semantics for control variables of fors.
  * new semantics for setn/getn.
  * new syntax/semantics for varargs.
  * new long strings and comments.
  * new `mod' operator (`%%')
  * new length operator #t
  * metatables for all types
  API:
  * new functions: lua_createtable, lua_get(set)field, lua_push(to)integer.
  * user supplies memory allocator (lua_open becomes lua_newstate).
  * luaopen_* functionst must be called through Lua.
  Implementation:
  * new configuration scheme via luaconf.h.
  * incremental garbage collection.
  * better handling of end-of-line in the lexer.
  * fully reentrant parser (new Lua function `load')
  * better support for 64-bit machines.
  * native loadlib support for Mac OS X.
  * standard distribution in only one library (lualib.a merged into lua.a)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
- Fix shared library linking.
* Thu Sep  8 2005 anicka@suse.cz
- enable dynamic loading capability (#106845)
* Fri Apr 23 2004 mcihar@suse.cz
- initial packaging
